/*
    Copyright (C) 2010  Kevin Funk <krf@electrostorm.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/

#include "testrunner_mobile.h"

#include <QtCore/QDebug>
#include <QtTest/QtTest>

#include <solid/battery.h>
#include <solid/device.h>
#include <solid/networking.h>
#include <solid/networkinterface.h>

QTEST_MAIN(TestRunner_Mobile)

QString toString( Solid::Networking::Status st )
{
  QString str;
  switch ( st ) {
    case Solid::Networking::Unknown:
      str = "Unknown";
      break;
    case Solid::Networking::Unconnected:
      str = "Unconnected";
      break;
    case Solid::Networking::Disconnecting:
      str = "Disconnecting";
      break;
    case Solid::Networking::Connecting:
      str = "Connecting";
      break;
    case Solid::Networking::Connected:
      str = "Connected";
      break;
  }
  return str;
}

void TestRunner_Mobile::initTestCase()
{
}

void TestRunner_Mobile::testPrintNetworkStatus()
{
    qDebug() << "Network status:" << toString(Solid::Networking::status());
}

void TestRunner_Mobile::testPrintRandomInformation()
{
    foreach (Solid::Device device, Solid::Device::allDevices())
    {
        qDebug() << "Device:" << device.udi();

        Solid::Battery* bat = device.as< Solid::Battery >();
        if ( bat ) {
            qDebug() << "Battery UDI:" << bat << device.udi();
            qDebug() << "Battery Life:" << bat->chargePercent();
        }
        Solid::NetworkInterface* nic = device.as< Solid::NetworkInterface >();
        if ( nic ) {
            qDebug() << "NIC UDI:" << nic << device.udi();
            qDebug() << "NIC MAC:" << nic->macAddress();
            qDebug() << "NIC Name:" << nic->ifaceName();
            qDebug() << "NIC Address:" << nic->hwAddress();
        }
        qDebug() << "next...";
    }
}
